summaryrefslogtreecommitdiffstats
path: root/include/clang/Driver/ToolChain.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/clang/Driver/ToolChain.h')
-rw-r--r--include/clang/Driver/ToolChain.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/include/clang/Driver/ToolChain.h b/include/clang/Driver/ToolChain.h
index f0012bd..da6949f 100644
--- a/include/clang/Driver/ToolChain.h
+++ b/include/clang/Driver/ToolChain.h
@@ -88,8 +88,10 @@ public:
return 0;
}
- /// SelectTool - Choose a tool to use to handle the action \arg JA.
- virtual Tool &SelectTool(const Compilation &C, const JobAction &JA) const = 0;
+ /// SelectTool - Choose a tool to use to handle the action \arg JA with the
+ /// given \arg Inputs.
+ virtual Tool &SelectTool(const Compilation &C, const JobAction &JA,
+ const ActionList &Inputs) const = 0;
// Helper methods
@@ -151,6 +153,9 @@ public:
/// particular PIC mode.
virtual const char *GetForcedPicModel() const = 0;
+ /// SupportsProfiling - Does this tool chain support -pg.
+ virtual bool SupportsProfiling() const { return true; }
+
/// Does this tool chain support Objective-C garbage collection.
virtual bool SupportsObjCGC() const { return false; }
OpenPOWER on IntegriCloud